Enum IsStringValue

pub enum IsStringValue {
    No,
    Yes,
}
Whether or not the plaintext has an implicit trailing null byte. This should be set to Yes for secrets inside files, and to No for the decryption key.

Variants



No



Yes